from tigrisdb.client import TigrisClient  # noqa: F401
from tigrisdb.collection import Collection  # noqa: F401
from tigrisdb.database import Database  # noqa: F401
from tigrisdb.search import Search  # noqa: F401
from tigrisdb.search_index import SearchIndex  # noqa: F401
from tigrisdb.vector_store import VectorStore  # noqa: F401



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: openapiv3/annotations.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..openapiv3 import OpenAPIv3_pb2 as openapiv3_dot_OpenAPIv3__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bopenapiv3/annotations.proto\x12\nopenapi.v3\x1a\x19openapiv3/OpenAPIv3.proto\x1a google/protobuf/descriptor.proto:E\n\x08\x64ocument\x12\x1c.google.protobuf.FileOptions\x18\xf7\x08 \x01(\x0b\x32\x14.openapi.v3.Document:I\n\toperation\x12\x1e.google.protobuf.MethodOptions\x18\xf7\x08 \x01(\x0b\x32\x15.openapi.v3.Operation:D\n\x06schema\x12\x1f.google.protobuf.MessageOptions\x18\xf7\x08 \x01(\x0b\x32\x12.openapi.v3.Schema:D\n\x08property\x12\x1d.google.protobuf.FieldOptions\x18\xf7\x08 \x01(\x0b\x32\x12.openapi.v3.SchemaBZ\n\x0eorg.openapi_v3B\x10\x41nnotationsProtoP\x01Z.github.com/google/gnostic/openapiv3;openapi_v3\xa2\x02\x03OASb\x06proto3')


DOCUMENT_FIELD_NUMBER = 1143
document = DESCRIPTOR.extensions_by_name['document']
OPERATION_FIELD_NUMBER = 1143
operation = DESCRIPTOR.extensions_by_name['operation']
SCHEMA_FIELD_NUMBER = 1143
schema = DESCRIPTOR.extensions_by_name['schema']
PROPERTY_FIELD_NUMBER = 1143
property = DESCRIPTOR.extensions_by_name['property']

if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(document)
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(operation)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(schema)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(property)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016org.openapi_v3B\020AnnotationsProtoP\001Z.github.com/google/gnostic/openapiv3;openapi_v3\242\002\003OAS'
# @@protoc_insertion_point(module_scope)



import grpc

from api.generated.server.v1.api_pb2 import (
    CreateOrUpdateCollectionRequest,
    CreateOrUpdateCollectionResponse,
    DropCollectionRequest,
    DropCollectionResponse,
)
from api.generated.server.v1.api_pb2_grpc import TigrisStub
from tigrisdb.collection import Collection
from tigrisdb.errors import TigrisException, TigrisServerError
from tigrisdb.types import ClientConfig
from tigrisdb.utils import schema_to_bytes


class Database:
    __client: TigrisStub
    __config: ClientConfig

    def __init__(self, client_stub: TigrisStub, config: ClientConfig):
        self.__client = client_stub
        self.__config = config

    @property
    def project(self):
        return self.__config.project

    @property
    def branch(self):
        return self.__config.branch

    def create_or_update_collection(self, name: str, schema: dict) -> Collection:
        req = CreateOrUpdateCollectionRequest(
            project=self.project,
            branch=self.branch,
            collection=name,
            schema=schema_to_bytes(schema),
            only_create=False,
        )
        try:
            resp: CreateOrUpdateCollectionResponse = (
                self.__client.CreateOrUpdateCollection(req)
            )
        except grpc.RpcError as e:
            raise TigrisServerError("failed to create collection", e)

        if resp.status == "created":
            return Collection(name, self.__client, self.__config)
        else:
            raise TigrisException(f"failed to create collection: {resp.message}")

    def drop_collection(self, name: str) -> bool:
        req = DropCollectionRequest(
            project=self.project,
            branch=self.branch,
            collection=name,
        )

        try:
            resp: DropCollectionResponse = self.__client.DropCollection(req)
        except grpc.RpcError as e:
            raise TigrisServerError("failed to drop collection", e)
        return resp.status == "dropped"



from typing import Union

from .logical import And, LogicalFilter, Or  # noqa: F401
from .selector import (  # noqa: F401
    GT,
    GTE,
    LT,
    LTE,
    Contains,
    Eq,
    Not,
    Regex,
    SelectorFilter,
)

Filter = Union[LogicalFilter, SelectorFilter]



from random import randint
from time import time

import grpc

from api.generated.server.v1 import auth_pb2_grpc as tigris_auth
from api.generated.server.v1.auth_pb2 import (
    CLIENT_CREDENTIALS,
    GetAccessTokenRequest,
    GetAccessTokenResponse,
)
from tigrisdb.errors import TigrisException, TigrisServerError
from tigrisdb.types import ClientConfig
from tigrisdb.utils import b64_to_object


class AuthGateway(grpc.AuthMetadataPlugin):
    __cached_token: str = ""
    __next_refresh_time: float = 0.0
    __config: ClientConfig
    __auth_stub: tigris_auth.AuthStub

    def __init__(self, config: ClientConfig):
        super(grpc.AuthMetadataPlugin, self).__init__()
        self.__config = config
        channel = grpc.secure_channel(config.server_url, grpc.ssl_channel_credentials())
        try:
            grpc.channel_ready_future(channel).result(timeout=10)
        except grpc.FutureTimeoutError:
            raise TigrisException(f"Auth connection timed out: {config.server_url}")
        self.__auth_stub = tigris_auth.AuthStub(channel)

    def get_access_token(self):
        if self.should_refresh():
            req = GetAccessTokenRequest(
                grant_type=CLIENT_CREDENTIALS,
                client_id=self.__config.client_id,
                client_secret=self.__config.client_secret,
            )
            try:
                resp: GetAccessTokenResponse = self.__auth_stub.GetAccessToken(req)
                self.__cached_token = resp.access_token
                token_meta = b64_to_object(self.__cached_token.split(".")[1] + "==")
                exp = float(token_meta["exp"])
                self.__next_refresh_time = exp - 300 - float(randint(0, 300) + 60)
            except grpc.RpcError as e:
                raise TigrisServerError("failed to get access token", e)
        return self.__cached_token

    def should_refresh(self):
        return (not self.__cached_token) or time() >= self.__next_refresh_time

    def get_auth_headers(self, context: grpc.AuthMetadataContext):
        headers = (
            ("authorization", f"Bearer {self.get_access_token()}"),
            ("user-agent", "tigris-client-python.grpc"),
            ("destination-name", self.__config.server_url),
        )
        return headers

    def __call__(self, context, callback):
        """Implements authentication by passing metadata to a callback.

        This method will be invoked asynchronously in a separate thread.

        Args:
          context: An AuthMetadataContext providing information on the RPC that
            the plugin is being called to authenticate.
          callback: An AuthMetadataPluginCallback to be invoked either
            synchronously or asynchronously.
        """
        callback(self.get_auth_headers(context), None)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ...server.v1 import search_pb2 as server_dot_v1_dot_search__pb2


class SearchStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateOrUpdateIndex = channel.unary_unary(
                '/tigrisdata.search.v1.Search/CreateOrUpdateIndex',
                request_serializer=server_dot_v1_dot_search__pb2.CreateOrUpdateIndexRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_search__pb2.CreateOrUpdateIndexResponse.FromString,
                )
        self.GetIndex = channel.unary_unary(
                '/tigrisdata.search.v1.Search/GetIndex',
                request_serializer=server_dot_v1_dot_search__pb2.GetIndexRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_search__pb2.GetIndexResponse.FromString,
                )
        self.DeleteIndex = channel.unary_unary(
                '/tigrisdata.search.v1.Search/DeleteIndex',
                request_serializer=server_dot_v1_dot_search__pb2.DeleteIndexRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_search__pb2.DeleteIndexResponse.FromString,
                )
        self.ListIndexes = channel.unary_unary(
                '/tigrisdata.search.v1.Search/ListIndexes',
                request_serializer=server_dot_v1_dot_search__pb2.ListIndexesRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_search__pb2.ListIndexesResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/tigrisdata.search.v1.Search/Get',
                request_serializer=server_dot_v1_dot_search__pb2.GetDocumentRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_search__pb2.GetDocumentResponse.FromString,
                )
        self.CreateById = channel.unary_unary(
                '/tigrisdata.search.v1.Search/CreateById',
                request_serializer=server_dot_v1_dot_search__pb2.CreateByIdRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_search__pb2.CreateByIdResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/tigrisdata.search.v1.Search/Create',
                request_serializer=server_dot_v1_dot_search__pb2.CreateDocumentRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_search__pb2.CreateDocumentResponse.FromString,
                )
        self.CreateOrReplace = channel.unary_unary(
                '/tigrisdata.search.v1.Search/CreateOrReplace',
                request_serializer=server_dot_v1_dot_search__pb2.CreateOrReplaceDocumentRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_search__pb2.CreateOrReplaceDocumentResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/tigrisdata.search.v1.Search/Update',
                request_serializer=server_dot_v1_dot_search__pb2.UpdateDocumentRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_search__pb2.UpdateDocumentResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/tigrisdata.search.v1.Search/Delete',
                request_serializer=server_dot_v1_dot_search__pb2.DeleteDocumentRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_search__pb2.DeleteDocumentResponse.FromString,
                )
        self.DeleteByQuery = channel.unary_unary(
                '/tigrisdata.search.v1.Search/DeleteByQuery',
                request_serializer=server_dot_v1_dot_search__pb2.DeleteByQueryRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_search__pb2.DeleteByQueryResponse.FromString,
                )
        self.Search = channel.unary_stream(
                '/tigrisdata.search.v1.Search/Search',
                request_serializer=server_dot_v1_dot_search__pb2.SearchIndexRequest.SerializeToString,
                response_deserializer=server_dot_v1_dot_search__pb2.SearchIndexResponse.FromString,
                )


class SearchServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateOrUpdateIndex(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIndex(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIndex(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListIndexes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Retrieves one or more documents by id. The response is an array of documents in the same order it is requests.
        A null is returned for the documents that are not found.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateById(self, request, context):
        """CreateById is used for indexing a single document. The API expects a single document. An "id" is optional
        and the server can automatically generate it for you in case it is missing. In cases an id is provided in
        the document and the document already exists then that document will not be indexed and an error is returned
        with HTTP status code 409.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Create is used for indexing a single or multiple documents. The API expects an array of documents.
        Each document is a JSON object. An "id" is optional and the server can automatically generate it for you in
        case it is missing. In cases when an id is provided in the document and the document already exists then that
        document will not be indexed and in the response there will be an error corresponding to that document id other
        documents will succeed. Returns an array of status indicating the status of each document.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrReplace(self, request, context):
        """Creates or replaces one or more documents. Each document is a JSON object. A document is replaced
        if it already exists. An "id" is generated automatically in case it is missing in the document. The
        document is created if "id" doesn't exists otherwise it is replaced. Returns an array of status indicating
        the status of each document.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates one or more documents by "id". Each document is required to have the
        "id" field in it. Returns an array of status indicating the status of each document. Each status
        has an error field that is set to null in case document is updated successfully otherwise the error
        field is set with a code and message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete one or more documents by id. Returns an array of status indicating the status of each document. Each status
        has an error field that is set to null in case document is deleted successfully otherwise it will non null with
        an error code and message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteByQuery(self, request, context):
        """DeleteByQuery is used to delete documents that match the filter. A filter is required. To delete document by id,
        you can pass the filter as follows ```{"id": "test"}```. Returns a count of number of documents deleted.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Search(self, request, context):
        """Searches an index for the documents matching the query. A search can be a term search or a phrase search.
        Search API allows filtering the result set using filters as documented
        <a href="https://docs.tigrisdata.com/overview/query#specification-1" title="here">here</a>. You can also perform
        a faceted search by passing the fields in the facet parameter. You can find more detailed documentation of the
        Search API with multiple examples <a href="https://docs.tigrisdata.com/overview/search" title="here">here</a>.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SearchServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateOrUpdateIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrUpdateIndex,
                    request_deserializer=server_dot_v1_dot_search__pb2.CreateOrUpdateIndexRequest.FromString,
                    response_serializer=server_dot_v1_dot_search__pb2.CreateOrUpdateIndexResponse.SerializeToString,
            ),
            'GetIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIndex,
                    request_deserializer=server_dot_v1_dot_search__pb2.GetIndexRequest.FromString,
                    response_serializer=server_dot_v1_dot_search__pb2.GetIndexResponse.SerializeToString,
            ),
            'DeleteIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIndex,
                    request_deserializer=server_dot_v1_dot_search__pb2.DeleteIndexRequest.FromString,
                    response_serializer=server_dot_v1_dot_search__pb2.DeleteIndexResponse.SerializeToString,
            ),
            'ListIndexes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIndexes,
                    request_deserializer=server_dot_v1_dot_search__pb2.ListIndexesRequest.FromString,
                    response_serializer=server_dot_v1_dot_search__pb2.ListIndexesResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=server_dot_v1_dot_search__pb2.GetDocumentRequest.FromString,
                    response_serializer=server_dot_v1_dot_search__pb2.GetDocumentResponse.SerializeToString,
            ),
            'CreateById': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateById,
                    request_deserializer=server_dot_v1_dot_search__pb2.CreateByIdRequest.FromString,
                    response_serializer=server_dot_v1_dot_search__pb2.CreateByIdResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=server_dot_v1_dot_search__pb2.CreateDocumentRequest.FromString,
                    response_serializer=server_dot_v1_dot_search__pb2.CreateDocumentResponse.SerializeToString,
            ),
            'CreateOrReplace': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrReplace,
                    request_deserializer=server_dot_v1_dot_search__pb2.CreateOrReplaceDocumentRequest.FromString,
                    response_serializer=server_dot_v1_dot_search__pb2.CreateOrReplaceDocumentResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=server_dot_v1_dot_search__pb2.UpdateDocumentRequest.FromString,
                    response_serializer=server_dot_v1_dot_search__pb2.UpdateDocumentResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=server_dot_v1_dot_search__pb2.DeleteDocumentRequest.FromString,
                    response_serializer=server_dot_v1_dot_search__pb2.DeleteDocumentResponse.SerializeToString,
            ),
            'DeleteByQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteByQuery,
                    request_deserializer=server_dot_v1_dot_search__pb2.DeleteByQueryRequest.FromString,
                    response_serializer=server_dot_v1_dot_search__pb2.DeleteByQueryResponse.SerializeToString,
            ),
            'Search': grpc.unary_stream_rpc_method_handler(
                    servicer.Search,
                    request_deserializer=server_dot_v1_dot_search__pb2.SearchIndexRequest.FromString,
                    response_serializer=server_dot_v1_dot_search__pb2.SearchIndexResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tigrisdata.search.v1.Search', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Search(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateOrUpdateIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.search.v1.Search/CreateOrUpdateIndex',
            server_dot_v1_dot_search__pb2.CreateOrUpdateIndexRequest.SerializeToString,
            server_dot_v1_dot_search__pb2.CreateOrUpdateIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.search.v1.Search/GetIndex',
            server_dot_v1_dot_search__pb2.GetIndexRequest.SerializeToString,
            server_dot_v1_dot_search__pb2.GetIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.search.v1.Search/DeleteIndex',
            server_dot_v1_dot_search__pb2.DeleteIndexRequest.SerializeToString,
            server_dot_v1_dot_search__pb2.DeleteIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListIndexes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.search.v1.Search/ListIndexes',
            server_dot_v1_dot_search__pb2.ListIndexesRequest.SerializeToString,
            server_dot_v1_dot_search__pb2.ListIndexesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.search.v1.Search/Get',
            server_dot_v1_dot_search__pb2.GetDocumentRequest.SerializeToString,
            server_dot_v1_dot_search__pb2.GetDocumentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.search.v1.Search/CreateById',
            server_dot_v1_dot_search__pb2.CreateByIdRequest.SerializeToString,
            server_dot_v1_dot_search__pb2.CreateByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.search.v1.Search/Create',
            server_dot_v1_dot_search__pb2.CreateDocumentRequest.SerializeToString,
            server_dot_v1_dot_search__pb2.CreateDocumentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrReplace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.search.v1.Search/CreateOrReplace',
            server_dot_v1_dot_search__pb2.CreateOrReplaceDocumentRequest.SerializeToString,
            server_dot_v1_dot_search__pb2.CreateOrReplaceDocumentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.search.v1.Search/Update',
            server_dot_v1_dot_search__pb2.UpdateDocumentRequest.SerializeToString,
            server_dot_v1_dot_search__pb2.UpdateDocumentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.search.v1.Search/Delete',
            server_dot_v1_dot_search__pb2.DeleteDocumentRequest.SerializeToString,
            server_dot_v1_dot_search__pb2.DeleteDocumentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteByQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tigrisdata.search.v1.Search/DeleteByQuery',
            server_dot_v1_dot_search__pb2.DeleteByQueryRequest.SerializeToString,
            server_dot_v1_dot_search__pb2.DeleteByQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Search(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/tigrisdata.search.v1.Search/Search',
            server_dot_v1_dot_search__pb2.SearchIndexRequest.SerializeToString,
            server_dot_v1_dot_search__pb2.SearchIndexResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: openapiv3/OpenAPIv3.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19openapiv3/OpenAPIv3.proto\x12\nopenapi.v3\x1a\x19google/protobuf/any.proto\"t\n\x18\x41\x64\x64itionalPropertiesItem\x12<\n\x13schema_or_reference\x18\x01 \x01(\x0b\x32\x1d.openapi.v3.SchemaOrReferenceH\x00\x12\x11\n\x07\x62oolean\x18\x02 \x01(\x08H\x00\x42\x07\n\x05oneof\"8\n\x03\x41ny\x12#\n\x05value\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"h\n\x0f\x41nyOrExpression\x12\x1e\n\x03\x61ny\x18\x01 \x01(\x0b\x32\x0f.openapi.v3.AnyH\x00\x12,\n\nexpression\x18\x02 \x01(\x0b\x32\x16.openapi.v3.ExpressionH\x00\x42\x07\n\x05oneof\"j\n\x08\x43\x61llback\x12\'\n\x04path\x18\x01 \x03(\x0b\x32\x19.openapi.v3.NamedPathItem\x12\x35\n\x17specification_extension\x18\x02 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"t\n\x13\x43\x61llbackOrReference\x12(\n\x08\x63\x61llback\x18\x01 \x01(\x0b\x32\x14.openapi.v3.CallbackH\x00\x12*\n\treference\x18\x02 \x01(\x0b\x32\x15.openapi.v3.ReferenceH\x00\x42\x07\n\x05oneof\"\\\n\x15\x43\x61llbacksOrReferences\x12\x43\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32$.openapi.v3.NamedCallbackOrReference\"\xaf\x04\n\nComponents\x12\x30\n\x07schemas\x18\x01 \x01(\x0b\x32\x1f.openapi.v3.SchemasOrReferences\x12\x34\n\tresponses\x18\x02 \x01(\x0b\x32!.openapi.v3.ResponsesOrReferences\x12\x36\n\nparameters\x18\x03 \x01(\x0b\x32\".openapi.v3.ParametersOrReferences\x12\x32\n\x08\x65xamples\x18\x04 \x01(\x0b\x32 .openapi.v3.ExamplesOrReferences\x12=\n\x0erequest_bodies\x18\x05 \x01(\x0b\x32%.openapi.v3.RequestBodiesOrReferences\x12\x30\n\x07headers\x18\x06 \x01(\x0b\x32\x1f.openapi.v3.HeadersOrReferences\x12\x41\n\x10security_schemes\x18\x07 \x01(\x0b\x32\'.openapi.v3.SecuritySchemesOrReferences\x12,\n\x05links\x18\x08 \x01(\x0b\x32\x1d.openapi.v3.LinksOrReferences\x12\x34\n\tcallbacks\x18\t \x01(\x0b\x32!.openapi.v3.CallbacksOrReferences\x12\x35\n\x17specification_extension\x18\n \x03(\x0b\x32\x14.openapi.v3.NamedAny\"j\n\x07\x43ontact\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x35\n\x17specification_extension\x18\x04 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"M\n\x0b\x44\x65\x66\x61ultType\x12\x10\n\x06number\x18\x01 \x01(\x01H\x00\x12\x11\n\x07\x62oolean\x18\x02 \x01(\x08H\x00\x12\x10\n\x06string\x18\x03 \x01(\tH\x00\x42\x07\n\x05oneof\"\x83\x01\n\rDiscriminator\x12\x15\n\rproperty_name\x18\x01 \x01(\t\x12$\n\x07mapping\x18\x02 \x01(\x0b\x32\x13.openapi.v3.Strings\x12\x35\n\x17specification_extension\x18\x03 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"\xe8\x02\n\x08\x44ocument\x12\x0f\n\x07openapi\x18\x01 \x01(\t\x12\x1e\n\x04info\x18\x02 \x01(\x0b\x32\x10.openapi.v3.Info\x12#\n\x07servers\x18\x03 \x03(\x0b\x32\x12.openapi.v3.Server\x12 \n\x05paths\x18\x04 \x01(\x0b\x32\x11.openapi.v3.Paths\x12*\n\ncomponents\x18\x05 \x01(\x0b\x32\x16.openapi.v3.Components\x12\x31\n\x08security\x18\x06 \x03(\x0b\x32\x1f.openapi.v3.SecurityRequirement\x12\x1d\n\x04tags\x18\x07 \x03(\x0b\x32\x0f.openapi.v3.Tag\x12/\n\rexternal_docs\x18\x08 \x01(\x0b\x32\x18.openapi.v3.ExternalDocs\x12\x35\n\x17specification_extension\x18\t \x03(\x0b\x32\x14.openapi.v3.NamedAny\"\xc1\x01\n\x08\x45ncoding\x12\x14\n\x0c\x63ontent_type\x18\x01 \x01(\t\x12\x30\n\x07headers\x18\x02 \x01(\x0b\x32\x1f.openapi.v3.HeadersOrReferences\x12\r\n\x05style\x18\x03 \x01(\t\x12\x0f\n\x07\x65xplode\x18\x04 \x01(\x08\x12\x16\n\x0e\x61llow_reserved\x18\x05 \x01(\x08\x12\x35\n\x17specification_extension\x18\x06 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"E\n\tEncodings\x12\x38\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\x19.openapi.v3.NamedEncoding\"\x9e\x01\n\x07\x45xample\x12\x0f\n\x07summary\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1e\n\x05value\x18\x03 \x01(\x0b\x32\x0f.openapi.v3.Any\x12\x16\n\x0e\x65xternal_value\x18\x04 \x01(\t\x12\x35\n\x17specification_extension\x18\x05 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"q\n\x12\x45xampleOrReference\x12&\n\x07\x65xample\x18\x01 \x01(\x0b\x32\x13.openapi.v3.ExampleH\x00\x12*\n\treference\x18\x02 \x01(\x0b\x32\x15.openapi.v3.ReferenceH\x00\x42\x07\n\x05oneof\"Z\n\x14\x45xamplesOrReferences\x12\x42\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32#.openapi.v3.NamedExampleOrReference\"A\n\nExpression\x12\x33\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"g\n\x0c\x45xternalDocs\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x35\n\x17specification_extension\x18\x03 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"\xfb\x02\n\x06Header\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08required\x18\x02 \x01(\x08\x12\x12\n\ndeprecated\x18\x03 \x01(\x08\x12\x19\n\x11\x61llow_empty_value\x18\x04 \x01(\x08\x12\r\n\x05style\x18\x05 \x01(\t\x12\x0f\n\x07\x65xplode\x18\x06 \x01(\x08\x12\x16\n\x0e\x61llow_reserved\x18\x07 \x01(\x08\x12-\n\x06schema\x18\x08 \x01(\x0b\x32\x1d.openapi.v3.SchemaOrReference\x12 \n\x07\x65xample\x18\t \x01(\x0b\x32\x0f.openapi.v3.Any\x12\x32\n\x08\x65xamples\x18\n \x01(\x0b\x32 .openapi.v3.ExamplesOrReferences\x12\'\n\x07\x63ontent\x18\x0b \x01(\x0b\x32\x16.openapi.v3.MediaTypes\x12\x35\n\x17specification_extension\x18\x0c \x03(\x0b\x32\x14.openapi.v3.NamedAny\"n\n\x11HeaderOrReference\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x12.openapi.v3.HeaderH\x00\x12*\n\treference\x18\x02 \x01(\x0b\x32\x15.openapi.v3.ReferenceH\x00\x42\x07\n\x05oneof\"X\n\x13HeadersOrReferences\x12\x41\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\".openapi.v3.NamedHeaderOrReference\"\xe9\x01\n\x04Info\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x18\n\x10terms_of_service\x18\x03 \x01(\t\x12$\n\x07\x63ontact\x18\x04 \x01(\x0b\x32\x13.openapi.v3.Contact\x12$\n\x07license\x18\x05 \x01(\x0b\x32\x13.openapi.v3.License\x12\x0f\n\x07version\x18\x06 \x01(\t\x12\x35\n\x17specification_extension\x18\x07 \x03(\x0b\x32\x14.openapi.v3.NamedAny\x12\x0f\n\x07summary\x18\x08 \x01(\t\"G\n\tItemsItem\x12:\n\x13schema_or_reference\x18\x01 \x03(\x0b\x32\x1d.openapi.v3.SchemaOrReference\"[\n\x07License\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x35\n\x17specification_extension\x18\x03 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"\x87\x02\n\x04Link\x12\x15\n\roperation_ref\x18\x01 \x01(\t\x12\x14\n\x0coperation_id\x18\x02 \x01(\t\x12/\n\nparameters\x18\x03 \x01(\x0b\x32\x1b.openapi.v3.AnyOrExpression\x12\x31\n\x0crequest_body\x18\x04 \x01(\x0b\x32\x1b.openapi.v3.AnyOrExpression\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\"\n\x06server\x18\x06 \x01(\x0b\x32\x12.openapi.v3.Server\x12\x35\n\x17specification_extension\x18\x07 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"h\n\x0fLinkOrReference\x12 \n\x04link\x18\x01 \x01(\x0b\x32\x10.openapi.v3.LinkH\x00\x12*\n\treference\x18\x02 \x01(\x0b\x32\x15.openapi.v3.ReferenceH\x00\x42\x07\n\x05oneof\"T\n\x11LinksOrReferences\x12?\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32 .openapi.v3.NamedLinkOrReference\"\xf0\x01\n\tMediaType\x12-\n\x06schema\x18\x01 \x01(\x0b\x32\x1d.openapi.v3.SchemaOrReference\x12 \n\x07\x65xample\x18\x02 \x01(\x0b\x32\x0f.openapi.v3.Any\x12\x32\n\x08\x65xamples\x18\x03 \x01(\x0b\x32 .openapi.v3.ExamplesOrReferences\x12\'\n\x08\x65ncoding\x18\x04 \x01(\x0b\x32\x15.openapi.v3.Encodings\x12\x35\n\x17specification_extension\x18\x05 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"G\n\nMediaTypes\x12\x39\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\x1a.openapi.v3.NamedMediaType\"8\n\x08NamedAny\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.openapi.v3.Any\"X\n\x18NamedCallbackOrReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.openapi.v3.CallbackOrReference\"B\n\rNamedEncoding\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.openapi.v3.Encoding\"V\n\x17NamedExampleOrReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.openapi.v3.ExampleOrReference\"T\n\x16NamedHeaderOrReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.openapi.v3.HeaderOrReference\"P\n\x14NamedLinkOrReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.openapi.v3.LinkOrReference\"D\n\x0eNamedMediaType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.openapi.v3.MediaType\"Z\n\x19NamedParameterOrReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .openapi.v3.ParameterOrReference\"B\n\rNamedPathItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.openapi.v3.PathItem\"^\n\x1bNamedRequestBodyOrReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".openapi.v3.RequestBodyOrReference\"X\n\x18NamedResponseOrReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.openapi.v3.ResponseOrReference\"T\n\x16NamedSchemaOrReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.openapi.v3.SchemaOrReference\"d\n\x1eNamedSecuritySchemeOrReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.openapi.v3.SecuritySchemeOrReference\"N\n\x13NamedServerVariable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.openapi.v3.ServerVariable\"*\n\x0bNamedString\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"H\n\x10NamedStringArray\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.openapi.v3.StringArray\"\xaa\x01\n\tOauthFlow\x12\x19\n\x11\x61uthorization_url\x18\x01 \x01(\t\x12\x11\n\ttoken_url\x18\x02 \x01(\t\x12\x13\n\x0brefresh_url\x18\x03 \x01(\t\x12#\n\x06scopes\x18\x04 \x01(\x0b\x32\x13.openapi.v3.Strings\x12\x35\n\x17specification_extension\x18\x05 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"\xfb\x01\n\nOauthFlows\x12\'\n\x08implicit\x18\x01 \x01(\x0b\x32\x15.openapi.v3.OauthFlow\x12\'\n\x08password\x18\x02 \x01(\x0b\x32\x15.openapi.v3.OauthFlow\x12\x31\n\x12\x63lient_credentials\x18\x03 \x01(\x0b\x32\x15.openapi.v3.OauthFlow\x12\x31\n\x12\x61uthorization_code\x18\x04 \x01(\x0b\x32\x15.openapi.v3.OauthFlow\x12\x35\n\x17specification_extension\x18\x05 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"=\n\x06Object\x12\x33\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"\xf9\x03\n\tOperation\x12\x0c\n\x04tags\x18\x01 \x03(\t\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12/\n\rexternal_docs\x18\x04 \x01(\x0b\x32\x18.openapi.v3.ExternalDocs\x12\x14\n\x0coperation_id\x18\x05 \x01(\t\x12\x34\n\nparameters\x18\x06 \x03(\x0b\x32 .openapi.v3.ParameterOrReference\x12\x38\n\x0crequest_body\x18\x07 \x01(\x0b\x32\".openapi.v3.RequestBodyOrReference\x12(\n\tresponses\x18\x08 \x01(\x0b\x32\x15.openapi.v3.Responses\x12\x34\n\tcallbacks\x18\t \x01(\x0b\x32!.openapi.v3.CallbacksOrReferences\x12\x12\n\ndeprecated\x18\n \x01(\x08\x12\x31\n\x08security\x18\x0b \x03(\x0b\x32\x1f.openapi.v3.SecurityRequirement\x12#\n\x07servers\x18\x0c \x03(\x0b\x32\x12.openapi.v3.Server\x12\x35\n\x17specification_extension\x18\r \x03(\x0b\x32\x14.openapi.v3.NamedAny\"\x98\x03\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02in\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08required\x18\x04 \x01(\x08\x12\x12\n\ndeprecated\x18\x05 \x01(\x08\x12\x19\n\x11\x61llow_empty_value\x18\x06 \x01(\x08\x12\r\n\x05style\x18\x07 \x01(\t\x12\x0f\n\x07\x65xplode\x18\x08 \x01(\x08\x12\x16\n\x0e\x61llow_reserved\x18\t \x01(\x08\x12-\n\x06schema\x18\n \x01(\x0b\x32\x1d.openapi.v3.SchemaOrReference\x12 \n\x07\x65xample\x18\x0b \x01(\x0b\x32\x0f.openapi.v3.Any\x12\x32\n\x08\x65xamples\x18\x0c \x01(\x0b\x32 .openapi.v3.ExamplesOrReferences\x12\'\n\x07\x63ontent\x18\r \x01(\x0b\x32\x16.openapi.v3.MediaTypes\x12\x35\n\x17specification_extension\x18\x0e \x03(\x0b\x32\x14.openapi.v3.NamedAny\"w\n\x14ParameterOrReference\x12*\n\tparameter\x18\x01 \x01(\x0b\x32\x15.openapi.v3.ParameterH\x00\x12*\n\treference\x18\x02 \x01(\x0b\x32\x15.openapi.v3.ReferenceH\x00\x42\x07\n\x05oneof\"^\n\x16ParametersOrReferences\x12\x44\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32%.openapi.v3.NamedParameterOrReference\"\xfd\x03\n\x08PathItem\x12\x0c\n\x04_ref\x18\x01 \x01(\t\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\"\n\x03get\x18\x04 \x01(\x0b\x32\x15.openapi.v3.Operation\x12\"\n\x03put\x18\x05 \x01(\x0b\x32\x15.openapi.v3.Operation\x12#\n\x04post\x18\x06 \x01(\x0b\x32\x15.openapi.v3.Operation\x12%\n\x06\x64\x65lete\x18\x07 \x01(\x0b\x32\x15.openapi.v3.Operation\x12&\n\x07options\x18\x08 \x01(\x0b\x32\x15.openapi.v3.Operation\x12#\n\x04head\x18\t \x01(\x0b\x32\x15.openapi.v3.Operation\x12$\n\x05patch\x18\n \x01(\x0b\x32\x15.openapi.v3.Operation\x12$\n\x05trace\x18\x0b \x01(\x0b\x32\x15.openapi.v3.Operation\x12#\n\x07servers\x18\x0c \x03(\x0b\x32\x12.openapi.v3.Server\x12\x34\n\nparameters\x18\r \x03(\x0b\x32 .openapi.v3.ParameterOrReference\x12\x35\n\x17specification_extension\x18\x0e \x03(\x0b\x32\x14.openapi.v3.NamedAny\"g\n\x05Paths\x12\'\n\x04path\x18\x01 \x03(\x0b\x32\x19.openapi.v3.NamedPathItem\x12\x35\n\x17specification_extension\x18\x02 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"O\n\nProperties\x12\x41\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\".openapi.v3.NamedSchemaOrReference\"?\n\tReference\x12\x0c\n\x04_ref\x18\x01 \x01(\t\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"c\n\x19RequestBodiesOrReferences\x12\x46\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\'.openapi.v3.NamedRequestBodyOrReference\"\x94\x01\n\x0bRequestBody\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\'\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x16.openapi.v3.MediaTypes\x12\x10\n\x08required\x18\x03 \x01(\x08\x12\x35\n\x17specification_extension\x18\x04 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"~\n\x16RequestBodyOrReference\x12/\n\x0crequest_body\x18\x01 \x01(\x0b\x32\x17.openapi.v3.RequestBodyH\x00\x12*\n\treference\x18\x02 \x01(\x0b\x32\x15.openapi.v3.ReferenceH\x00\x42\x07\n\x05oneof\"\xdf\x01\n\x08Response\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x30\n\x07headers\x18\x02 \x01(\x0b\x32\x1f.openapi.v3.HeadersOrReferences\x12\'\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x16.openapi.v3.MediaTypes\x12,\n\x05links\x18\x04 \x01(\x0b\x32\x1d.openapi.v3.LinksOrReferences\x12\x35\n\x17specification_extension\x18\x05 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"t\n\x13ResponseOrReference\x12(\n\x08response\x18\x01 \x01(\x0b\x32\x14.openapi.v3.ResponseH\x00\x12*\n\treference\x18\x02 \x01(\x0b\x32\x15.openapi.v3.ReferenceH\x00\x42\x07\n\x05oneof\"\xb9\x01\n\tResponses\x12\x30\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x0b\x32\x1f.openapi.v3.ResponseOrReference\x12\x43\n\x15response_or_reference\x18\x02 \x03(\x0b\x32$.openapi.v3.NamedResponseOrReference\x12\x35\n\x17specification_extension\x18\x03 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"\\\n\x15ResponsesOrReferences\x12\x43\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32$.openapi.v3.NamedResponseOrReference\"\xa3\x08\n\x06Schema\x12\x10\n\x08nullable\x18\x01 \x01(\x08\x12\x30\n\rdiscriminator\x18\x02 \x01(\x0b\x32\x19.openapi.v3.Discriminator\x12\x11\n\tread_only\x18\x03 \x01(\x08\x12\x12\n\nwrite_only\x18\x04 \x01(\x08\x12\x1c\n\x03xml\x18\x05 \x01(\x0b\x32\x0f.openapi.v3.Xml\x12/\n\rexternal_docs\x18\x06 \x01(\x0b\x32\x18.openapi.v3.ExternalDocs\x12 \n\x07\x65xample\x18\x07 \x01(\x0b\x32\x0f.openapi.v3.Any\x12\x12\n\ndeprecated\x18\x08 \x01(\x08\x12\r\n\x05title\x18\t \x01(\t\x12\x13\n\x0bmultiple_of\x18\n \x01(\x01\x12\x0f\n\x07maximum\x18\x0b \x01(\x01\x12\x19\n\x11\x65xclusive_maximum\x18\x0c \x01(\x08\x12\x0f\n\x07minimum\x18\r \x01(\x01\x12\x19\n\x11\x65xclusive_minimum\x18\x0e \x01(\x08\x12\x12\n\nmax_length\x18\x0f \x01(\x03\x12\x12\n\nmin_length\x18\x10 \x01(\x03\x12\x0f\n\x07pattern\x18\x11 \x01(\t\x12\x11\n\tmax_items\x18\x12 \x01(\x03\x12\x11\n\tmin_items\x18\x13 \x01(\x03\x12\x14\n\x0cunique_items\x18\x14 \x01(\x08\x12\x16\n\x0emax_properties\x18\x15 \x01(\x03\x12\x16\n\x0emin_properties\x18\x16 \x01(\x03\x12\x10\n\x08required\x18\x17 \x03(\t\x12\x1d\n\x04\x65num\x18\x18 \x03(\x0b\x32\x0f.openapi.v3.Any\x12\x0c\n\x04type\x18\x19 \x01(\t\x12-\n\x06\x61ll_of\x18\x1a \x03(\x0b\x32\x1d.openapi.v3.SchemaOrReference\x12-\n\x06one_of\x18\x1b \x03(\x0b\x32\x1d.openapi.v3.SchemaOrReference\x12-\n\x06\x61ny_of\x18\x1c \x03(\x0b\x32\x1d.openapi.v3.SchemaOrReference\x12\x1f\n\x03not\x18\x1d \x01(\x0b\x32\x12.openapi.v3.Schema\x12$\n\x05items\x18\x1e \x01(\x0b\x32\x15.openapi.v3.ItemsItem\x12*\n\nproperties\x18\x1f \x01(\x0b\x32\x16.openapi.v3.Properties\x12\x43\n\x15\x61\x64\x64itional_properties\x18  \x01(\x0b\x32$.openapi.v3.AdditionalPropertiesItem\x12(\n\x07\x64\x65\x66\x61ult\x18! \x01(\x0b\x32\x17.openapi.v3.DefaultType\x12\x13\n\x0b\x64\x65scription\x18\" \x01(\t\x12\x0e\n\x06\x66ormat\x18# \x01(\t\x12\x35\n\x17specification_extension\x18$ \x03(\x0b\x32\x14.openapi.v3.NamedAny\"n\n\x11SchemaOrReference\x12$\n\x06schema\x18\x01 \x01(\x0b\x32\x12.openapi.v3.SchemaH\x00\x12*\n\treference\x18\x02 \x01(\x0b\x32\x15.openapi.v3.ReferenceH\x00\x42\x07\n\x05oneof\"X\n\x13SchemasOrReferences\x12\x41\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\".openapi.v3.NamedSchemaOrReference\"R\n\x13SecurityRequirement\x12;\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\x1c.openapi.v3.NamedStringArray\"\xef\x01\n\x0eSecurityScheme\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\n\n\x02in\x18\x04 \x01(\t\x12\x0e\n\x06scheme\x18\x05 \x01(\t\x12\x15\n\rbearer_format\x18\x06 \x01(\t\x12%\n\x05\x66lows\x18\x07 \x01(\x0b\x32\x16.openapi.v3.OauthFlows\x12\x1b\n\x13open_id_connect_url\x18\x08 \x01(\t\x12\x35\n\x17specification_extension\x18\t \x03(\x0b\x32\x14.openapi.v3.NamedAny\"\x87\x01\n\x19SecuritySchemeOrReference\x12\x35\n\x0fsecurity_scheme\x18\x01 \x01(\x0b\x32\x1a.openapi.v3.SecuritySchemeH\x00\x12*\n\treference\x18\x02 \x01(\x0b\x32\x15.openapi.v3.ReferenceH\x00\x42\x07\n\x05oneof\"h\n\x1bSecuritySchemesOrReferences\x12I\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32*.openapi.v3.NamedSecuritySchemeOrReference\"\x91\x01\n\x06Server\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12.\n\tvariables\x18\x03 \x01(\x0b\x32\x1b.openapi.v3.ServerVariables\x12\x35\n\x17specification_extension\x18\x04 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"{\n\x0eServerVariable\x12\x0c\n\x04\x65num\x18\x01 \x03(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x35\n\x17specification_extension\x18\x04 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"Q\n\x0fServerVariables\x12>\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\x1f.openapi.v3.NamedServerVariable\"X\n\x16SpecificationExtension\x12\x10\n\x06number\x18\x01 \x01(\x01H\x00\x12\x11\n\x07\x62oolean\x18\x02 \x01(\x08H\x00\x12\x10\n\x06string\x18\x03 \x01(\tH\x00\x42\x07\n\x05oneof\"\x1c\n\x0bStringArray\x12\r\n\x05value\x18\x01 \x03(\t\"A\n\x07Strings\x12\x36\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\x17.openapi.v3.NamedString\"\x90\x01\n\x03Tag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12/\n\rexternal_docs\x18\x03 \x01(\x0b\x32\x18.openapi.v3.ExternalDocs\x12\x35\n\x17specification_extension\x18\x04 \x03(\x0b\x32\x14.openapi.v3.NamedAny\"\x91\x01\n\x03Xml\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12\x11\n\tattribute\x18\x04 \x01(\x08\x12\x0f\n\x07wrapped\x18\x05 \x01(\x08\x12\x35\n\x17specification_extension\x18\x06 \x03(\x0b\x32\x14.openapi.v3.NamedAnyBV\n\x0eorg.openapi_v3B\x0cOpenAPIProtoP\x01Z.github.com/google/gnostic/openapiv3;openapi_v3\xa2\x02\x03OASb\x06proto3')



_ADDITIONALPROPERTIESITEM = DESCRIPTOR.message_types_by_name['AdditionalPropertiesItem']
_ANY = DESCRIPTOR.message_types_by_name['Any']
_ANYOREXPRESSION = DESCRIPTOR.message_types_by_name['AnyOrExpression']
_CALLBACK = DESCRIPTOR.message_types_by_name['Callback']
_CALLBACKORREFERENCE = DESCRIPTOR.message_types_by_name['CallbackOrReference']
_CALLBACKSORREFERENCES = DESCRIPTOR.message_types_by_name['CallbacksOrReferences']
_COMPONENTS = DESCRIPTOR.message_types_by_name['Components']
_CONTACT = DESCRIPTOR.message_types_by_name['Contact']
_DEFAULTTYPE = DESCRIPTOR.message_types_by_name['DefaultType']
_DISCRIMINATOR = DESCRIPTOR.message_types_by_name['Discriminator']
_DOCUMENT = DESCRIPTOR.message_types_by_name['Document']
_ENCODING = DESCRIPTOR.message_types_by_name['Encoding']
_ENCODINGS = DESCRIPTOR.message_types_by_name['Encodings']
_EXAMPLE = DESCRIPTOR.message_types_by_name['Example']
_EXAMPLEORREFERENCE = DESCRIPTOR.message_types_by_name['ExampleOrReference']
_EXAMPLESORREFERENCES = DESCRIPTOR.message_types_by_name['ExamplesOrReferences']
_EXPRESSION = DESCRIPTOR.message_types_by_name['Expression']
_EXTERNALDOCS = DESCRIPTOR.message_types_by_name['ExternalDocs']
_HEADER = DESCRIPTOR.message_types_by_name['Header']
_HEADERORREFERENCE = DESCRIPTOR.message_types_by_name['HeaderOrReference']
_HEADERSORREFERENCES = DESCRIPTOR.message_types_by_name['HeadersOrReferences']
_INFO = DESCRIPTOR.message_types_by_name['Info']
_ITEMSITEM = DESCRIPTOR.message_types_by_name['ItemsItem']
_LICENSE = DESCRIPTOR.message_types_by_name['License']
_LINK = DESCRIPTOR.message_types_by_name['Link']
_LINKORREFERENCE = DESCRIPTOR.message_types_by_name['LinkOrReference']
_LINKSORREFERENCES = DESCRIPTOR.message_types_by_name['LinksOrReferences']
_MEDIATYPE = DESCRIPTOR.message_types_by_name['MediaType']
_MEDIATYPES = DESCRIPTOR.message_types_by_name['MediaTypes']
_NAMEDANY = DESCRIPTOR.message_types_by_name['NamedAny']
_NAMEDCALLBACKORREFERENCE = DESCRIPTOR.message_types_by_name['NamedCallbackOrReference']
_NAMEDENCODING = DESCRIPTOR.message_types_by_name['NamedEncoding']
_NAMEDEXAMPLEORREFERENCE = DESCRIPTOR.message_types_by_name['NamedExampleOrReference']
_NAMEDHEADERORREFERENCE = DESCRIPTOR.message_types_by_name['NamedHeaderOrReference']
_NAMEDLINKORREFERENCE = DESCRIPTOR.message_types_by_name['NamedLinkOrReference']
_NAMEDMEDIATYPE = DESCRIPTOR.message_types_by_name['NamedMediaType']
_NAMEDPARAMETERORREFERENCE = DESCRIPTOR.message_types_by_name['NamedParameterOrReference']
_NAMEDPATHITEM = DESCRIPTOR.message_types_by_name['NamedPathItem']
_NAMEDREQUESTBODYORREFERENCE = DESCRIPTOR.message_types_by_name['NamedRequestBodyOrReference']
_NAMEDRESPONSEORREFERENCE = DESCRIPTOR.message_types_by_name['NamedResponseOrReference']
_NAMEDSCHEMAORREFERENCE = DESCRIPTOR.message_types_by_name['NamedSchemaOrReference']
_NAMEDSECURITYSCHEMEORREFERENCE = DESCRIPTOR.message_types_by_name['NamedSecuritySchemeOrReference']
_NAMEDSERVERVARIABLE = DESCRIPTOR.message_types_by_name['NamedServerVariable']
_NAMEDSTRING = DESCRIPTOR.message_types_by_name['NamedString']
_NAMEDSTRINGARRAY = DESCRIPTOR.message_types_by_name['NamedStringArray']
_OAUTHFLOW = DESCRIPTOR.message_types_by_name['OauthFlow']
_OAUTHFLOWS = DESCRIPTOR.message_types_by_name['OauthFlows']
_OBJECT = DESCRIPTOR.message_types_by_name['Object']
_OPERATION = DESCRIPTOR.message_types_by_name['Operation']
_PARAMETER = DESCRIPTOR.message_types_by_name['Parameter']
_PARAMETERORREFERENCE = DESCRIPTOR.message_types_by_name['ParameterOrReference']
_PARAMETERSORREFERENCES = DESCRIPTOR.message_types_by_name['ParametersOrReferences']
_PATHITEM = DESCRIPTOR.message_types_by_name['PathItem']
_PATHS = DESCRIPTOR.message_types_by_name['Paths']
_PROPERTIES = DESCRIPTOR.message_types_by_name['Properties']
_REFERENCE = DESCRIPTOR.message_types_by_name['Reference']
_REQUESTBODIESORREFERENCES = DESCRIPTOR.message_types_by_name['RequestBodiesOrReferences']
_REQUESTBODY = DESCRIPTOR.message_types_by_name['RequestBody']
_REQUESTBODYORREFERENCE = DESCRIPTOR.message_types_by_name['RequestBodyOrReference']
_RESPONSE = DESCRIPTOR.message_types_by_name['Response']
_RESPONSEORREFERENCE = DESCRIPTOR.message_types_by_name['ResponseOrReference']
_RESPONSES = DESCRIPTOR.message_types_by_name['Responses']
_RESPONSESORREFERENCES = DESCRIPTOR.message_types_by_name['ResponsesOrReferences']
_SCHEMA = DESCRIPTOR.message_types_by_name['Schema']
_SCHEMAORREFERENCE = DESCRIPTOR.message_types_by_name['SchemaOrReference']
_SCHEMASORREFERENCES = DESCRIPTOR.message_types_by_name['SchemasOrReferences']
_SECURITYREQUIREMENT = DESCRIPTOR.message_types_by_name['SecurityRequirement']
_SECURITYSCHEME = DESCRIPTOR.message_types_by_name['SecurityScheme']
_SECURITYSCHEMEORREFERENCE = DESCRIPTOR.message_types_by_name['SecuritySchemeOrReference']
_SECURITYSCHEMESORREFERENCES = DESCRIPTOR.message_types_by_name['SecuritySchemesOrReferences']
_SERVER = DESCRIPTOR.message_types_by_name['Server']
_SERVERVARIABLE = DESCRIPTOR.message_types_by_name['ServerVariable']
_SERVERVARIABLES = DESCRIPTOR.message_types_by_name['ServerVariables']
_SPECIFICATIONEXTENSION = DESCRIPTOR.message_types_by_name['SpecificationExtension']
_STRINGARRAY = DESCRIPTOR.message_types_by_name['StringArray']
_STRINGS = DESCRIPTOR.message_types_by_name['Strings']
_TAG = DESCRIPTOR.message_types_by_name['Tag']
_XML = DESCRIPTOR.message_types_by_name['Xml']
AdditionalPropertiesItem = _reflection.GeneratedProtocolMessageType('AdditionalPropertiesItem', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALPROPERTIESITEM,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.AdditionalPropertiesItem)
  })
_sym_db.RegisterMessage(AdditionalPropertiesItem)

Any = _reflection.GeneratedProtocolMessageType('Any', (_message.Message,), {
  'DESCRIPTOR' : _ANY,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Any)
  })
_sym_db.RegisterMessage(Any)

AnyOrExpression = _reflection.GeneratedProtocolMessageType('AnyOrExpression', (_message.Message,), {
  'DESCRIPTOR' : _ANYOREXPRESSION,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.AnyOrExpression)
  })
_sym_db.RegisterMessage(AnyOrExpression)

Callback = _reflection.GeneratedProtocolMessageType('Callback', (_message.Message,), {
  'DESCRIPTOR' : _CALLBACK,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Callback)
  })
_sym_db.RegisterMessage(Callback)

CallbackOrReference = _reflection.GeneratedProtocolMessageType('CallbackOrReference', (_message.Message,), {
  'DESCRIPTOR' : _CALLBACKORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.CallbackOrReference)
  })
_sym_db.RegisterMessage(CallbackOrReference)

CallbacksOrReferences = _reflection.GeneratedProtocolMessageType('CallbacksOrReferences', (_message.Message,), {
  'DESCRIPTOR' : _CALLBACKSORREFERENCES,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.CallbacksOrReferences)
  })
_sym_db.RegisterMessage(CallbacksOrReferences)

Components = _reflection.GeneratedProtocolMessageType('Components', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTS,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Components)
  })
_sym_db.RegisterMessage(Components)

Contact = _reflection.GeneratedProtocolMessageType('Contact', (_message.Message,), {
  'DESCRIPTOR' : _CONTACT,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Contact)
  })
_sym_db.RegisterMessage(Contact)

DefaultType = _reflection.GeneratedProtocolMessageType('DefaultType', (_message.Message,), {
  'DESCRIPTOR' : _DEFAULTTYPE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.DefaultType)
  })
_sym_db.RegisterMessage(DefaultType)

Discriminator = _reflection.GeneratedProtocolMessageType('Discriminator', (_message.Message,), {
  'DESCRIPTOR' : _DISCRIMINATOR,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Discriminator)
  })
_sym_db.RegisterMessage(Discriminator)

Document = _reflection.GeneratedProtocolMessageType('Document', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENT,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Document)
  })
_sym_db.RegisterMessage(Document)

Encoding = _reflection.GeneratedProtocolMessageType('Encoding', (_message.Message,), {
  'DESCRIPTOR' : _ENCODING,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Encoding)
  })
_sym_db.RegisterMessage(Encoding)

Encodings = _reflection.GeneratedProtocolMessageType('Encodings', (_message.Message,), {
  'DESCRIPTOR' : _ENCODINGS,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Encodings)
  })
_sym_db.RegisterMessage(Encodings)

Example = _reflection.GeneratedProtocolMessageType('Example', (_message.Message,), {
  'DESCRIPTOR' : _EXAMPLE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Example)
  })
_sym_db.RegisterMessage(Example)

ExampleOrReference = _reflection.GeneratedProtocolMessageType('ExampleOrReference', (_message.Message,), {
  'DESCRIPTOR' : _EXAMPLEORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.ExampleOrReference)
  })
_sym_db.RegisterMessage(ExampleOrReference)

ExamplesOrReferences = _reflection.GeneratedProtocolMessageType('ExamplesOrReferences', (_message.Message,), {
  'DESCRIPTOR' : _EXAMPLESORREFERENCES,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.ExamplesOrReferences)
  })
_sym_db.RegisterMessage(ExamplesOrReferences)

Expression = _reflection.GeneratedProtocolMessageType('Expression', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSION,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Expression)
  })
_sym_db.RegisterMessage(Expression)

ExternalDocs = _reflection.GeneratedProtocolMessageType('ExternalDocs', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALDOCS,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.ExternalDocs)
  })
_sym_db.RegisterMessage(ExternalDocs)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
  'DESCRIPTOR' : _HEADER,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Header)
  })
_sym_db.RegisterMessage(Header)

HeaderOrReference = _reflection.GeneratedProtocolMessageType('HeaderOrReference', (_message.Message,), {
  'DESCRIPTOR' : _HEADERORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.HeaderOrReference)
  })
_sym_db.RegisterMessage(HeaderOrReference)

HeadersOrReferences = _reflection.GeneratedProtocolMessageType('HeadersOrReferences', (_message.Message,), {
  'DESCRIPTOR' : _HEADERSORREFERENCES,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.HeadersOrReferences)
  })
_sym_db.RegisterMessage(HeadersOrReferences)

Info = _reflection.GeneratedProtocolMessageType('Info', (_message.Message,), {
  'DESCRIPTOR' : _INFO,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Info)
  })
_sym_db.RegisterMessage(Info)

ItemsItem = _reflection.GeneratedProtocolMessageType('ItemsItem', (_message.Message,), {
  'DESCRIPTOR' : _ITEMSITEM,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.ItemsItem)
  })
_sym_db.RegisterMessage(ItemsItem)

License = _reflection.GeneratedProtocolMessageType('License', (_message.Message,), {
  'DESCRIPTOR' : _LICENSE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.License)
  })
_sym_db.RegisterMessage(License)

Link = _reflection.GeneratedProtocolMessageType('Link', (_message.Message,), {
  'DESCRIPTOR' : _LINK,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Link)
  })
_sym_db.RegisterMessage(Link)

LinkOrReference = _reflection.GeneratedProtocolMessageType('LinkOrReference', (_message.Message,), {
  'DESCRIPTOR' : _LINKORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.LinkOrReference)
  })
_sym_db.RegisterMessage(LinkOrReference)

LinksOrReferences = _reflection.GeneratedProtocolMessageType('LinksOrReferences', (_message.Message,), {
  'DESCRIPTOR' : _LINKSORREFERENCES,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.LinksOrReferences)
  })
_sym_db.RegisterMessage(LinksOrReferences)

MediaType = _reflection.GeneratedProtocolMessageType('MediaType', (_message.Message,), {
  'DESCRIPTOR' : _MEDIATYPE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.MediaType)
  })
_sym_db.RegisterMessage(MediaType)

MediaTypes = _reflection.GeneratedProtocolMessageType('MediaTypes', (_message.Message,), {
  'DESCRIPTOR' : _MEDIATYPES,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.MediaTypes)
  })
_sym_db.RegisterMessage(MediaTypes)

NamedAny = _reflection.GeneratedProtocolMessageType('NamedAny', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDANY,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedAny)
  })
_sym_db.RegisterMessage(NamedAny)

NamedCallbackOrReference = _reflection.GeneratedProtocolMessageType('NamedCallbackOrReference', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDCALLBACKORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedCallbackOrReference)
  })
_sym_db.RegisterMessage(NamedCallbackOrReference)

NamedEncoding = _reflection.GeneratedProtocolMessageType('NamedEncoding', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDENCODING,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedEncoding)
  })
_sym_db.RegisterMessage(NamedEncoding)

NamedExampleOrReference = _reflection.GeneratedProtocolMessageType('NamedExampleOrReference', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDEXAMPLEORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedExampleOrReference)
  })
_sym_db.RegisterMessage(NamedExampleOrReference)

NamedHeaderOrReference = _reflection.GeneratedProtocolMessageType('NamedHeaderOrReference', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDHEADERORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedHeaderOrReference)
  })
_sym_db.RegisterMessage(NamedHeaderOrReference)

NamedLinkOrReference = _reflection.GeneratedProtocolMessageType('NamedLinkOrReference', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDLINKORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedLinkOrReference)
  })
_sym_db.RegisterMessage(NamedLinkOrReference)

NamedMediaType = _reflection.GeneratedProtocolMessageType('NamedMediaType', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDMEDIATYPE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedMediaType)
  })
_sym_db.RegisterMessage(NamedMediaType)

NamedParameterOrReference = _reflection.GeneratedProtocolMessageType('NamedParameterOrReference', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDPARAMETERORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedParameterOrReference)
  })
_sym_db.RegisterMessage(NamedParameterOrReference)

NamedPathItem = _reflection.GeneratedProtocolMessageType('NamedPathItem', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDPATHITEM,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedPathItem)
  })
_sym_db.RegisterMessage(NamedPathItem)

NamedRequestBodyOrReference = _reflection.GeneratedProtocolMessageType('NamedRequestBodyOrReference', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDREQUESTBODYORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedRequestBodyOrReference)
  })
_sym_db.RegisterMessage(NamedRequestBodyOrReference)

NamedResponseOrReference = _reflection.GeneratedProtocolMessageType('NamedResponseOrReference', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDRESPONSEORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedResponseOrReference)
  })
_sym_db.RegisterMessage(NamedResponseOrReference)

NamedSchemaOrReference = _reflection.GeneratedProtocolMessageType('NamedSchemaOrReference', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDSCHEMAORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedSchemaOrReference)
  })
_sym_db.RegisterMessage(NamedSchemaOrReference)

NamedSecuritySchemeOrReference = _reflection.GeneratedProtocolMessageType('NamedSecuritySchemeOrReference', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDSECURITYSCHEMEORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedSecuritySchemeOrReference)
  })
_sym_db.RegisterMessage(NamedSecuritySchemeOrReference)

NamedServerVariable = _reflection.GeneratedProtocolMessageType('NamedServerVariable', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDSERVERVARIABLE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedServerVariable)
  })
_sym_db.RegisterMessage(NamedServerVariable)

NamedString = _reflection.GeneratedProtocolMessageType('NamedString', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDSTRING,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedString)
  })
_sym_db.RegisterMessage(NamedString)

NamedStringArray = _reflection.GeneratedProtocolMessageType('NamedStringArray', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDSTRINGARRAY,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.NamedStringArray)
  })
_sym_db.RegisterMessage(NamedStringArray)

OauthFlow = _reflection.GeneratedProtocolMessageType('OauthFlow', (_message.Message,), {
  'DESCRIPTOR' : _OAUTHFLOW,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.OauthFlow)
  })
_sym_db.RegisterMessage(OauthFlow)

OauthFlows = _reflection.GeneratedProtocolMessageType('OauthFlows', (_message.Message,), {
  'DESCRIPTOR' : _OAUTHFLOWS,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.OauthFlows)
  })
_sym_db.RegisterMessage(OauthFlows)

Object = _reflection.GeneratedProtocolMessageType('Object', (_message.Message,), {
  'DESCRIPTOR' : _OBJECT,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Object)
  })
_sym_db.RegisterMessage(Object)

Operation = _reflection.GeneratedProtocolMessageType('Operation', (_message.Message,), {
  'DESCRIPTOR' : _OPERATION,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Operation)
  })
_sym_db.RegisterMessage(Operation)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETER,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Parameter)
  })
_sym_db.RegisterMessage(Parameter)

ParameterOrReference = _reflection.GeneratedProtocolMessageType('ParameterOrReference', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.ParameterOrReference)
  })
_sym_db.RegisterMessage(ParameterOrReference)

ParametersOrReferences = _reflection.GeneratedProtocolMessageType('ParametersOrReferences', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERSORREFERENCES,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.ParametersOrReferences)
  })
_sym_db.RegisterMessage(ParametersOrReferences)

PathItem = _reflection.GeneratedProtocolMessageType('PathItem', (_message.Message,), {
  'DESCRIPTOR' : _PATHITEM,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.PathItem)
  })
_sym_db.RegisterMessage(PathItem)

Paths = _reflection.GeneratedProtocolMessageType('Paths', (_message.Message,), {
  'DESCRIPTOR' : _PATHS,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Paths)
  })
_sym_db.RegisterMessage(Paths)

Properties = _reflection.GeneratedProtocolMessageType('Properties', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTIES,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Properties)
  })
_sym_db.RegisterMessage(Properties)

Reference = _reflection.GeneratedProtocolMessageType('Reference', (_message.Message,), {
  'DESCRIPTOR' : _REFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Reference)
  })
_sym_db.RegisterMessage(Reference)

RequestBodiesOrReferences = _reflection.GeneratedProtocolMessageType('RequestBodiesOrReferences', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTBODIESORREFERENCES,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.RequestBodiesOrReferences)
  })
_sym_db.RegisterMessage(RequestBodiesOrReferences)

RequestBody = _reflection.GeneratedProtocolMessageType('RequestBody', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTBODY,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.RequestBody)
  })
_sym_db.RegisterMessage(RequestBody)

RequestBodyOrReference = _reflection.GeneratedProtocolMessageType('RequestBodyOrReference', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTBODYORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.RequestBodyOrReference)
  })
_sym_db.RegisterMessage(RequestBodyOrReference)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Response)
  })
_sym_db.RegisterMessage(Response)

ResponseOrReference = _reflection.GeneratedProtocolMessageType('ResponseOrReference', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.ResponseOrReference)
  })
_sym_db.RegisterMessage(ResponseOrReference)

Responses = _reflection.GeneratedProtocolMessageType('Responses', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSES,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Responses)
  })
_sym_db.RegisterMessage(Responses)

ResponsesOrReferences = _reflection.GeneratedProtocolMessageType('ResponsesOrReferences', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSESORREFERENCES,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.ResponsesOrReferences)
  })
_sym_db.RegisterMessage(ResponsesOrReferences)

Schema = _reflection.GeneratedProtocolMessageType('Schema', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMA,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Schema)
  })
_sym_db.RegisterMessage(Schema)

SchemaOrReference = _reflection.GeneratedProtocolMessageType('SchemaOrReference', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMAORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.SchemaOrReference)
  })
_sym_db.RegisterMessage(SchemaOrReference)

SchemasOrReferences = _reflection.GeneratedProtocolMessageType('SchemasOrReferences', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMASORREFERENCES,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.SchemasOrReferences)
  })
_sym_db.RegisterMessage(SchemasOrReferences)

SecurityRequirement = _reflection.GeneratedProtocolMessageType('SecurityRequirement', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYREQUIREMENT,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.SecurityRequirement)
  })
_sym_db.RegisterMessage(SecurityRequirement)

SecurityScheme = _reflection.GeneratedProtocolMessageType('SecurityScheme', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYSCHEME,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.SecurityScheme)
  })
_sym_db.RegisterMessage(SecurityScheme)

SecuritySchemeOrReference = _reflection.GeneratedProtocolMessageType('SecuritySchemeOrReference', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYSCHEMEORREFERENCE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.SecuritySchemeOrReference)
  })
_sym_db.RegisterMessage(SecuritySchemeOrReference)

SecuritySchemesOrReferences = _reflection.GeneratedProtocolMessageType('SecuritySchemesOrReferences', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYSCHEMESORREFERENCES,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.SecuritySchemesOrReferences)
  })
_sym_db.RegisterMessage(SecuritySchemesOrReferences)

Server = _reflection.GeneratedProtocolMessageType('Server', (_message.Message,), {
  'DESCRIPTOR' : _SERVER,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Server)
  })
_sym_db.RegisterMessage(Server)

ServerVariable = _reflection.GeneratedProtocolMessageType('ServerVariable', (_message.Message,), {
  'DESCRIPTOR' : _SERVERVARIABLE,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.ServerVariable)
  })
_sym_db.RegisterMessage(ServerVariable)

ServerVariables = _reflection.GeneratedProtocolMessageType('ServerVariables', (_message.Message,), {
  'DESCRIPTOR' : _SERVERVARIABLES,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.ServerVariables)
  })
_sym_db.RegisterMessage(ServerVariables)

SpecificationExtension = _reflection.GeneratedProtocolMessageType('SpecificationExtension', (_message.Message,), {
  'DESCRIPTOR' : _SPECIFICATIONEXTENSION,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.SpecificationExtension)
  })
_sym_db.RegisterMessage(SpecificationExtension)

StringArray = _reflection.GeneratedProtocolMessageType('StringArray', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAY,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.StringArray)
  })
_sym_db.RegisterMessage(StringArray)

Strings = _reflection.GeneratedProtocolMessageType('Strings', (_message.Message,), {
  'DESCRIPTOR' : _STRINGS,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Strings)
  })
_sym_db.RegisterMessage(Strings)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
  'DESCRIPTOR' : _TAG,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Tag)
  })
_sym_db.RegisterMessage(Tag)

Xml = _reflection.GeneratedProtocolMessageType('Xml', (_message.Message,), {
  'DESCRIPTOR' : _XML,
  '__module__' : 'openapiv3.OpenAPIv3_pb2'
  # @@protoc_insertion_point(class_scope:openapi.v3.Xml)
  })
_sym_db.RegisterMessage(Xml)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016org.openapi_v3B\014OpenAPIProtoP\001Z.github.com/google/gnostic/openapiv3;openapi_v3\242\002\003OAS'
  _ADDITIONALPROPERTIESITEM._serialized_start=68
  _ADDITIONALPROPERTIESITEM._serialized_end=184
  _ANY._serialized_start=186
  _ANY._serialized_end=242
  _ANYOREXPRESSION._serialized_start=244
  _ANYOREXPRESSION._serialized_end=348
  _CALLBACK._serialized_start=350
  _CALLBACK._serialized_end=456
  _CALLBACKORREFERENCE._serialized_start=458
  _CALLBACKORREFERENCE._serialized_end=574
  _CALLBACKSORREFERENCES._serialized_start=576
  _CALLBACKSORREFERENCES._serialized_end=668
  _COMPONENTS._serialized_start=671
  _COMPONENTS._serialized_end=1230
  _CONTACT._serialized_start=1232
  _CONTACT._serialized_end=1338
  _DEFAULTTYPE._serialized_start=1340
  _DEFAULTTYPE._serialized_end=1417
  _DISCRIMINATOR._serialized_start=1420
  _DISCRIMINATOR._serialized_end=1551
  _DOCUMENT._serialized_start=1554
  _DOCUMENT._serialized_end=1914
  _ENCODING._serialized_start=1917
  _ENCODING._serialized_end=2110
  _ENCODINGS._serialized_start=2112
  _ENCODINGS._serialized_end=2181
  _EXAMPLE._serialized_start=2184
  _EXAMPLE._serialized_end=2342
  _EXAMPLEORREFERENCE._serialized_start=2344
  _EXAMPLEORREFERENCE._serialized_end=2457
  _EXAMPLESORREFERENCES._serialized_start=2459
  _EXAMPLESORREFERENCES._serialized_end=2549
  _EXPRESSION._serialized_start=2551
  _EXPRESSION._serialized_end=2616
  _EXTERNALDOCS._serialized_start=2618
  _EXTERNALDOCS._serialized_end=2721
  _HEADER._serialized_start=2724
  _HEADER._serialized_end=3103
  _HEADERORREFERENCE._serialized_start=3105
  _HEADERORREFERENCE._serialized_end=3215
  _HEADERSORREFERENCES._serialized_start=3217
  _HEADERSORREFERENCES._serialized_end=3305
  _INFO._serialized_start=3308
  _INFO._serialized_end=3541
  _ITEMSITEM._serialized_start=3543
  _ITEMSITEM._serialized_end=3614
  _LICENSE._serialized_start=3616
  _LICENSE._serialized_end=3707
  _LINK._serialized_start=3710
  _LINK._serialized_end=3973
  _LINKORREFERENCE._serialized_start=3975
  _LINKORREFERENCE._serialized_end=4079
  _LINKSORREFERENCES._serialized_start=4081
  _LINKSORREFERENCES._serialized_end=4165
  _MEDIATYPE._serialized_start=4168
  _MEDIATYPE._serialized_end=4408
  _MEDIATYPES._serialized_start=4410
  _MEDIATYPES._serialized_end=4481
  _NAMEDANY._serialized_start=4483
  _NAMEDANY._serialized_end=4539
  _NAMEDCALLBACKORREFERENCE._serialized_start=4541
  _NAMEDCALLBACKORREFERENCE._serialized_end=4629
  _NAMEDENCODING._serialized_start=4631
  _NAMEDENCODING._serialized_end=4697
  _NAMEDEXAMPLEORREFERENCE._serialized_start=4699
  _NAMEDEXAMPLEORREFERENCE._serialized_end=4785
  _NAMEDHEADERORREFERENCE._serialized_start=4787
  _NAMEDHEADERORREFERENCE._serialized_end=4871
  _NAMEDLINKORREFERENCE._serialized_start=4873
  _NAMEDLINKORREFERENCE._serialized_end=4953
  _NAMEDMEDIATYPE._serialized_start=4955
  _NAMEDMEDIATYPE._serialized_end=5023
  _NAMEDPARAMETERORREFERENCE._serialized_start=5025
  _NAMEDPARAMETERORREFERENCE._serialized_end=5115
  _NAMEDPATHITEM._serialized_start=5117
  _NAMEDPATHITEM._serialized_end=5183
  _NAMEDREQUESTBODYORREFERENCE._serialized_start=5185
  _NAMEDREQUESTBODYORREFERENCE._serialized_end=5279
  _NAMEDRESPONSEORREFERENCE._serialized_start=5281
  _NAMEDRESPONSEORREFERENCE._serialized_end=5369
  _NAMEDSCHEMAORREFERENCE._serialized_start=5371
  _NAMEDSCHEMAORREFERENCE._serialized_end=5455
  _NAMEDSECURITYSCHEMEORREFERENCE._serialized_start=5457
  _NAMEDSECURITYSCHEMEORREFERENCE._serialized_end=5557
  _NAMEDSERVERVARIABLE._serialized_start=5559
  _NAMEDSERVERVARIABLE._serialized_end=5637
  _NAMEDSTRING._serialized_start=5639
  _NAMEDSTRING._serialized_end=5681
  _NAMEDSTRINGARRAY._serialized_start=5683
  _NAMEDSTRINGARRAY._serialized_end=5755
  _OAUTHFLOW._serialized_start=5758
  _OAUTHFLOW._serialized_end=5928
  _OAUTHFLOWS._serialized_start=5931
  _OAUTHFLOWS._serialized_end=6182
  _OBJECT._serialized_start=6184
  _OBJECT._serialized_end=6245
  _OPERATION._serialized_start=6248
  _OPERATION._serialized_end=6753
  _PARAMETER._serialized_start=6756
  _PARAMETER._serialized_end=7164
  _PARAMETERORREFERENCE._serialized_start=7166
  _PARAMETERORREFERENCE._serialized_end=7285
  _PARAMETERSORREFERENCES._serialized_start=7287
  _PARAMETERSORREFERENCES._serialized_end=7381
  _PATHITEM._serialized_start=7384
  _PATHITEM._serialized_end=7893
  _PATHS._serialized_start=7895
  _PATHS._serialized_end=7998
  _PROPERTIES._serialized_start=8000
  _PROPERTIES._serialized_end=8079
  _REFERENCE._serialized_start=8081
  _REFERENCE._serialized_end=8144
  _REQUESTBODIESORREFERENCES._serialized_start=8146
  _REQUESTBODIESORREFERENCES._serialized_end=8245
  _REQUESTBODY._serialized_start=8248
  _REQUESTBODY._serialized_end=8396
  _REQUESTBODYORREFERENCE._serialized_start=8398
  _REQUESTBODYORREFERENCE._serialized_end=8524
  _RESPONSE._serialized_start=8527
  _RESPONSE._serialized_end=8750
  _RESPONSEORREFERENCE._serialized_start=8752
  _RESPONSEORREFERENCE._serialized_end=8868
  _RESPONSES._serialized_start=8871
  _RESPONSES._serialized_end=9056
  _RESPONSESORREFERENCES._serialized_start=9058
  _RESPONSESORREFERENCES._serialized_end=9150
  _SCHEMA._serialized_start=9153
  _SCHEMA._serialized_end=10212
  _SCHEMAORREFERENCE._serialized_start=10214
  _SCHEMAORREFERENCE._serialized_end=10324
  _SCHEMASORREFERENCES._serialized_start=10326
  _SCHEMASORREFERENCES._serialized_end=10414
  _SECURITYREQUIREMENT._serialized_start=10416
  _SECURITYREQUIREMENT._serialized_end=10498
  _SECURITYSCHEME._serialized_start=10501
  _SECURITYSCHEME._serialized_end=10740
  _SECURITYSCHEMEORREFERENCE._serialized_start=10743
  _SECURITYSCHEMEORREFERENCE._serialized_end=10878
  _SECURITYSCHEMESORREFERENCES._serialized_start=10880
  _SECURITYSCHEMESORREFERENCES._serialized_end=10984
  _SERVER._serialized_start=10987
  _SERVER._serialized_end=11132
  _SERVERVARIABLE._serialized_start=11134
  _SERVERVARIABLE._serialized_end=11257
  _SERVERVARIABLES._serialized_start=11259
  _SERVERVARIABLES._serialized_end=11340
  _SPECIFICATIONEXTENSION._serialized_start=11342
  _SPECIFICATIONEXTENSION._serialized_end=11430
  _STRINGARRAY._serialized_start=11432
  _STRINGARRAY._serialized_end=11460
  _STRINGS._serialized_start=11462
  _STRINGS._serialized_end=11527
  _TAG._serialized_start=11530
  _TAG._serialized_end=11674
  _XML._serialized_start=11677
  _XML._serialized_end=11822
# @@protoc_insertion_point(module_scope)



from typing import Iterator, List

import grpc

from api.generated.server.v1.search_pb2 import (
    CreateDocumentRequest,
    CreateDocumentResponse,
    CreateOrReplaceDocumentRequest,
    CreateOrReplaceDocumentResponse,
    DeleteDocumentRequest,
    DeleteDocumentResponse,
    GetDocumentRequest,
    GetDocumentResponse,
    SearchIndexRequest,
    SearchIndexResponse,
    UpdateDocumentRequest,
    UpdateDocumentResponse,
)
from api.generated.server.v1.search_pb2_grpc import SearchStub
from tigrisdb.errors import TigrisServerError
from tigrisdb.types import ClientConfig, Document
from tigrisdb.types.search import DocStatus, IndexedDoc
from tigrisdb.types.search import Query as SearchQuery
from tigrisdb.types.search import Result as SearchResult
from tigrisdb.utils import marshal


class SearchIndex:
    __client: SearchStub
    __config: ClientConfig
    __name: str

    def __init__(self, index_name: str, client: SearchStub, config: ClientConfig):
        self.__client = client
        self.__name = index_name
        self.__config = config

    @property
    def project(self):
        return self.__config.project

    @property
    def name(self):
        return self.__name

    def search(self, query: SearchQuery, page: int = 1) -> SearchResult:
        req = SearchIndexRequest(project=self.project, index=self.name, page=page)
        query.__build__(req)
        try:
            result_iterator: Iterator[SearchIndexResponse] = self.__client.Search(req)
        except grpc.RpcError as e:
            raise TigrisServerError("failed to search documents", e)
        # only single page of result will be returned
        for res in result_iterator:
            return SearchResult(_p=res)

    def create_many(self, docs: List[Document]) -> List[DocStatus]:
        doc_bytes = map(marshal, docs)
        req = CreateDocumentRequest(
            project=self.project, index=self.name, documents=doc_bytes
        )

        try:
            resp: CreateDocumentResponse = self.__client.Create(req)
        except grpc.RpcError as e:
            raise TigrisServerError("failed to index documents", e)

        return [DocStatus(_p=d) for d in resp.status]

    def create_one(self, doc: Document) -> DocStatus:
        return self.create_many([doc])[0]

    def delete_many(self, doc_ids: List[str]) -> List[DocStatus]:
        req = DeleteDocumentRequest(project=self.project, index=self.name, ids=doc_ids)

        try:
            resp: DeleteDocumentResponse = self.__client.Delete(req)
        except grpc.RpcError as e:
            raise TigrisServerError("failed to delete documents", e)

        return [DocStatus(_p=d) for d in resp.status]

    def delete_one(self, doc_id: str) -> DocStatus:
        return self.delete_many([doc_id])[0]

    def delete_by_query(self):
        raise NotImplementedError("deletion by filters is not supported yet")

    def create_or_replace_many(self, docs: List[Document]) -> List[DocStatus]:
        doc_bytes = map(marshal, docs)
        req = CreateOrReplaceDocumentRequest(
            project=self.project, index=self.name, documents=doc_bytes
        )
        try:
            resp: CreateOrReplaceDocumentResponse = self.__client.CreateOrReplace(req)
        except grpc.RpcError as e:
            raise TigrisServerError("failed to create or replace documents", e)
        return [DocStatus(_p=d) for d in resp.status]

    def create_or_replace_one(self, doc: Document) -> DocStatus:
        return self.create_or_replace_many([doc])[0]

    def get_many(self, doc_ids: List[str]) -> List[IndexedDoc]:
        req = GetDocumentRequest(project=self.project, index=self.name, ids=doc_ids)

        try:
            resp: GetDocumentResponse = self.__client.Get(req)
        except grpc.RpcError as e:
            raise TigrisServerError("failed to get documents", e)

        return [IndexedDoc(_p=hit) for hit in resp.documents]

    def get_one(self, doc_id: str) -> IndexedDoc:
        return self.get_many([doc_id])[0]

    def update_many(self, docs: List[Document]) -> List[DocStatus]:
        doc_bytes = map(marshal, docs)
        req = UpdateDocumentRequest(
            project=self.project, index=self.name, documents=doc_bytes
        )

        try:
            resp: UpdateDocumentResponse = self.__client.Update(req)
        except grpc.RpcError as e:
            raise TigrisServerError("failed to update documents", e)

        return [*map(lambda d: DocStatus(_p=d), resp.status)]

    def update_one(self, doc: Document) -> DocStatus:
        return self.update_many([doc])[0]



import abc
import os
from dataclasses import dataclass
from typing import Dict, Optional, Type

Document: Type[dict] = Dict


@dataclass
class ClientConfig:
    project: str = ""
    client_id: Optional[str] = None
    client_secret: Optional[str] = None
    branch: str = ""
    server_url: str = ""

    def __post_init__(self):
        self.server_url = self.server_url or os.getenv(
            "TIGRIS_URI", "api.preview.tigrisdata.cloud"
        )
        self.project = self.project or os.getenv("TIGRIS_PROJECT")
        self.client_id = self.client_id or os.getenv("TIGRIS_CLIENT_ID")
        self.client_secret = self.client_secret or os.getenv("TIGRIS_CLIENT_SECRET")
        self.branch = self.branch or os.getenv("TIGRIS_DB_BRANCH", "")

    def merge(self, **kwargs):
        self.project = kwargs.get("project", self.project)
        self.server_url = kwargs.get("server_url", self.server_url)
        self.client_id = kwargs.get("client_id", self.client_id)
        self.client_secret = kwargs.get("client_secret", self.client_secret)
        self.branch = kwargs.get("branch", self.branch)

    def is_local_dev(self) -> bool:
        return any(
            map(
                lambda k: k in self.server_url,
                ["localhost", "127.0.0.1", "tigrisdb-local-server:", "[::1]"],
            )
        )

    def validate(self):
        is_remote = not self.is_local_dev()
        if not self.project:
            raise ValueError("Failed to resolve `TIGRIS_PROJECT` environment variable")
        if is_remote and not self.client_id:
            raise ValueError(
                "Failed to resolve `TIGRIS_CLIENT_ID` environment variable"
            )
        if is_remote and not self.client_secret:
            raise ValueError(
                "Failed to resolve `TIGRIS_CLIENT_SECRET` environment variable"
            )


class Serializable(abc.ABC):
    @abc.abstractmethod
    def query(self) -> Dict:
        raise NotImplementedError()


class BaseOperator(abc.ABC):
    @property
    @abc.abstractmethod
    def operator(self):
        raise NotImplementedError()



import os
from typing import Union

import grpc

from api.generated.server.v1.api_pb2_grpc import TigrisStub
from api.generated.server.v1.search_pb2_grpc import SearchStub
from tigrisdb.auth import AuthGateway
from tigrisdb.database import Database
from tigrisdb.errors import TigrisException
from tigrisdb.search import Search
from tigrisdb.types import ClientConfig
from tigrisdb.vector_store import VectorStore


class TigrisClient(object):
    __PREVIEW_URI = "api.preview.tigrisdata.cloud"

    __tigris_client: TigrisStub
    __search_client: SearchStub
    __config: ClientConfig

    def __init__(self, conf: Union[ClientConfig, dict, None] = None):
        os.environ["PROTOCOL_BUFFERS_PYTHON_IMPLEMENTATION"] = "python"

        if not conf:
            config = ClientConfig()
        elif isinstance(conf, dict):
            config = ClientConfig()
            config.merge(**conf)
        else:
            config = conf

        if config.server_url.startswith("https://"):
            config.server_url = config.server_url.replace("https://", "")
        if config.server_url.startswith("http://"):
            config.server_url = config.server_url.replace("http://", "")
        if ":" not in config.server_url:
            config.server_url = f"{config.server_url}:443"

        config.validate()
        if config.is_local_dev():
            channel = grpc.insecure_channel(config.server_url)
        else:
            auth_gtwy = AuthGateway(config)
            channel_creds = grpc.ssl_channel_credentials()
            call_creds = grpc.metadata_call_credentials(auth_gtwy, name="auth gateway")
            channel = grpc.secure_channel(
                config.server_url,
                grpc.composite_channel_credentials(channel_creds, call_creds),
            )

        try:
            grpc.channel_ready_future(channel).result(timeout=10)
        except grpc.FutureTimeoutError:
            raise TigrisException(f"Connection timed out {config.server_url}")

        self.__config = config
        self.__tigris_client = TigrisStub(channel)
        self._database = Database(self.__tigris_client, self.__config)
        self.__search_client = SearchStub(channel)
        self._search = Search(self.__search_client, self.__config)

    @property
    def config(self):
        return self.__config

    def get_db(self) -> Database:
        return self._database

    def get_search(self) -> Search:
        return self._search

    def get_vector_store(self, name: str) -> VectorStore:
        return VectorStore(self._search, name)
